@@ -19,18 +19,37 @@
 #define CONFIGOBJECT_H
 
 #include <qstring.h>
-#include <qptrlist.h>
-#include <qvaluelist.h>
+#include <q3ptrlist.h>
+#include <q3valuelist.h>
 #include <qfile.h>
-#include <qtextstream.h>
+#include <q3textstream.h>
 #include <qkeysequence.h>
+#include <qdom.h>
+#include <qmap.h>
+#include <QHash>
 
 typedef enum {
     MIDI_EMPTY            = 0,
     MIDI_KEY              = 1,
-    MIDI_CTRL             = 2
+    MIDI_CTRL             = 2,
+    MIDI_PITCH            = 3
 } MidiType;
 
+typedef enum {
+    MIDI_OPT_NORMAL           = 0,
+    MIDI_OPT_INVERT           = 1,
+    MIDI_OPT_ROT64            = 2,
+    MIDI_OPT_ROT64_INV        = 3,
+    MIDI_OPT_ROT64_FAST       = 4,
+    MIDI_OPT_DIFF             = 5,
+    MIDI_OPT_BUTTON           = 6, // Button Down (!=00) and Button Up (00) events happen together
+    MIDI_OPT_SWITCH           = 7, // Button Down (!=00) and Button Up (00) events happen seperately
+    MIDI_OPT_HERC_JOG         = 8, // Generic hercules wierd range correction
+    MIDI_OPT_SPREAD64         = 9, // Accelerated difference from 64
+    MIDI_OPT_SELECTKNOB       = 10,// Relative knob which can be turned forever and outputs a signed value.
+} MidiOption;
+
+typedef QMap<char,char> MidiValueMap;
 
 /*
   Class for the key for a specific configuration element. A key consists of a
@@ -41,10 +60,20 @@ class ConfigKey
 public:
     ConfigKey();
     ConfigKey(QString g, QString i);
-
+   
     QString group, item;
 };
 
+/* comparison function for ConfigKeys. Used by a QHash in ControlObject */
+inline bool operator==(const ConfigKey &c1, const ConfigKey &c2) {
+    return c1.group == c2.group && c1.item == c2.item;
+}
+
+/* QHash hash function for ConfigKey objects. */
+inline uint qHash(const ConfigKey &key) {
+    return qHash(key.group) ^ qHash(key.item);
+}
+
 /*
   The value corresponding to a key. The basic value is a string, but can be
   subclassed to more specific needs.
@@ -55,9 +84,11 @@ public:
     ConfigValue();
     ConfigValue(QString _value);
     ConfigValue(int _value);
+    inline ConfigValue(QDomNode /* node */) { qFatal("ConfigValue from QDomNode not implemented here"); }
     void valCopy(const ConfigValue _value);
 
     QString value;
+    friend bool operator==(const ConfigValue & s1, const ConfigValue & s2);
 };
 
 class ConfigValueMidi : public ConfigValue
@@ -66,10 +97,18 @@ public:
     ConfigValueMidi();
     ConfigValueMidi(QString _value);
     ConfigValueMidi(MidiType _miditype, int _midino, int _midichannel);
+    ConfigValueMidi(QDomNode node);
     void valCopy(const ConfigValueMidi v);
+    char translateValue(char value);
+    double ComputeValue(MidiType _miditype, double _prevmidivalue, double _newmidivalue);
+    friend bool operator==(const ConfigValueMidi & s1, const ConfigValueMidi & s2);
 
     MidiType miditype;
     int midino, midichannel;
+    unsigned int sensitivity;
+    MidiOption midioption;
+    // BJW: Static translation of MIDI values for this object, defined in the mapping file.
+    MidiValueMap translateMidiValues;
 };
 
 class ConfigValueKbd : public ConfigValue
@@ -78,7 +117,9 @@ public:
     ConfigValueKbd();
     ConfigValueKbd(QString _value);
     ConfigValueKbd(QKeySequence key);
+    inline ConfigValueKbd(QDomNode /* node */) { qFatal("ConfigValueKbd from QDomNode not implemented here"); }
     void valCopy(const ConfigValueKbd v);
+    friend bool operator==(const ConfigValueKbd & s1, const ConfigValueKbd & s2);
 
     QKeySequence m_qKey;
 };
@@ -100,6 +141,7 @@ template <class ValueType> class ConfigObject
     ConfigOption<ValueType> option;
 
     ConfigObject(QString file);
+	ConfigObject(QDomNode node);
     ~ConfigObject();
     ConfigOption<ValueType> *set(ConfigKey, ValueType);
     ConfigOption<ValueType> *get(ConfigKey key);
@@ -109,9 +151,10 @@ template <class ValueType> class ConfigObject
     void clear();
     void reopen(QString file);
     void Save();
+    QString getConfigPath();
 
   protected:
-    QPtrList< ConfigOption<ValueType> > list;
+    Q3PtrList< ConfigOption<ValueType> > list;
     QString filename;
 
     /** Loads and parses the configuration file. Returns false if the file could
@@ -121,3 +164,4 @@ template <class ValueType> class ConfigObject
 
 #endif
 
+
