@@ -9,14 +9,18 @@
 // Copyright: See COPYING file that comes with this distribution
 //
 //
+
+#include <qapplication.h>
+#include <QtDebug>
+//Added by qt3to4:
+#include <QEvent>
 #include "controlobjectthreadmain.h"
 #include "controlobject.h"
 #include "controlevent.h"
-#include <qapplication.h>
 
-
-ControlObjectThreadMain::ControlObjectThreadMain(ControlObject *pControlObject) : ControlObjectThread(pControlObject)
+ControlObjectThreadMain::ControlObjectThreadMain(ControlObject * pControlObject) : ControlObjectThread(pControlObject)
 {
+    setObjectName("ControlObjectThreadMain");
     installEventFilter(this);
 }
 
@@ -24,20 +28,19 @@ ControlObjectThreadMain::~ControlObjectThreadMain()
 {
 }
 
-bool ControlObjectThreadMain::eventFilter(QObject *o, QEvent *e)
+bool ControlObjectThreadMain::eventFilter(QObject * o, QEvent * e)
 {
-    // Handle mouse press events
+    // Handle events
     if (e->type() == 10000)
     {
-        ControlEvent *ce = (ControlEvent *)e;
-    
-        m_sqMutex.lock();
-        m_dValue = ce->value();
-        m_sqMutex.unlock();
+        ControlEvent * ce = (ControlEvent *)e;
 
-        //qDebug("ControlEvent %f",ce->value());
-        
-        emit(valueChanged(ce->value()));        
+        m_dataMutex.lock();
+        m_dValue = ce->value();
+        m_dataMutex.unlock();
+
+        //qDebug() << "ControlEvent " << ce->value();
+        emit(valueChanged(ce->value()));
     }
     else
     {
@@ -49,7 +52,7 @@ bool ControlObjectThreadMain::eventFilter(QObject *o, QEvent *e)
 
 bool ControlObjectThreadMain::setExtern(double v)
 {
-    //qDebug("set extern main");
+    //qDebug() << "set extern main";
     QApplication::postEvent(this, new ControlEvent(v));
     return true;
 }
