@@ -18,10 +18,11 @@
 #ifndef DLGPREFCONTROLS_H
 #define DLGPREFCONTROLS_H
 
-#include <qwidget.h>
-#include "dlgprefcontrolsdlg.h"
+#include "ui_dlgprefcontrolsdlg.h"
 #include "configobject.h"
+#include "mixxx.h"
 
+class QWidget;
 class ControlObjectThreadMain;
 class ControlPotmeter;
 class MixxxView;
@@ -30,24 +31,27 @@ class MixxxView;
   *@author Tue & Ken Haste Andersen
   */
 
-class DlgPrefControls : public DlgPrefControlsDlg  {
+class DlgPrefControls : public QWidget, public Ui::DlgPrefControlsDlg  {
     Q_OBJECT
 public: 
-    DlgPrefControls(QWidget *parent, MixxxView *pView, ConfigObject<ConfigValue> *pConfig);
+    DlgPrefControls(QWidget *parent, MixxxView *pView, MixxxApp *mixxx, ConfigObject<ConfigValue> *pConfig);
     ~DlgPrefControls();
 public slots:
     void slotUpdate();
     void slotSetRateRange(int pos);
     void slotSetRateDir(int pos);
-    void slotSetRateTempLeft(int);
-    void slotSetRateTempRight(int);
-    void slotSetRatePermLeft(int);
-    void slotSetRatePermRight(int);
+    void slotSetRateTempLeft(double);
+    void slotSetRateTempRight(double);
+    void slotSetRatePermLeft(double);
+    void slotSetRatePermRight(double);
     void slotSetVisuals(int pos);
     void slotSetScaleBpm(int pos);
     void slotSetTooltips(int pos);
     void slotSetSkin(int);
+	void slotSetScheme(int);
+	void slotUpdateSchemes();
     void slotSetPositionDisplay(int);
+    void slotSetCueDefault(int);
     void slotApply();
 private:
     /** Pointer to ConfigObject */
@@ -56,8 +60,11 @@ private:
     ControlObjectThreadMain *m_pControlRate1, *m_pControlRate2, *m_pControlRateRange1, *m_pControlRateRange2;
     /** Pointer to ControlObjects for controlling direction of rate sliders */
     ControlObjectThreadMain *m_pControlRateDir1, *m_pControlRateDir2;
+    /** Pointer to ControlObjects for cue behavior */
+    ControlObjectThreadMain *m_pControlCueDefault1, *m_pControlCueDefault2;
     /** Pointer to MixxxView */
     MixxxView *m_pView;
+	MixxxApp *m_mixxx;
 };
 
 #endif
