@@ -12,13 +12,13 @@
 #include "mixxxsocketserver.h"
 #include "mixxxsocketclient.h"
 
-MixxxSocketServer::MixxxSocketServer(Track *pTrack, QObject *parent, const char *name) : QServerSocket(QHostAddress(0x7f000001), 33033, 1, parent, name)
+MixxxSocketServer::MixxxSocketServer(Track * pTrack, QObject * parent, const char * name) : Q3ServerSocket(QHostAddress(0x7f000001), 33033, 1, parent, name)
 {
     m_pTrack = pTrack;
 
     if (!ok())
     {
-        qDebug("Failed to bind to port 33033");
+        qDebug() << "Failed to bind to port 33033";
     }
 }
 
