@@ -11,15 +11,18 @@
 //
 
 #include "parser.h"
+//Added by qt3to4:
+#include <Q3PtrList>
+#include <QtDebug>
 
 /**
-@author Ingo Kossyk (kossyki@cs.tu-berlin.de)
-**/
+   @author Ingo Kossyk (kossyki@cs.tu-berlin.de)
+ **/
 
 
 Parser::Parser()
 {
-    m_psLocations = new QPtrList<QString>;
+    m_psLocations = new Q3PtrList<QString>;
 }
 
 Parser::~Parser()
@@ -56,7 +59,7 @@ bool Parser::isBinary(QString filename){
     int i = 0;
 
 
-    if(file->open(IO_ReadOnly)){
+    if(file->open(QIODevice::ReadOnly)){
         if(( i = file->getch())<33){ //Starting byte is no character
             file->close();
             return true;
@@ -67,7 +70,7 @@ bool Parser::isBinary(QString filename){
             return true;
         }
 
-    }else{
+    } else{
         qDebug("Parser: Could not open file: "+filename);
     }
     //qDebug(QString("Parser: textstream starting character is: %1").arg(i));
